LoadAny class

加载更多 Widget

Inheritance

Constructors

LoadAny({required LoadStatus status, required CustomScrollView child, required LoadMoreCallback onLoadMore, bool endLoadMore = true, double bottomTriggerDistance = 200, double footerHeight = 40, LoadMoreBuilder? loadMoreBuilder, String loadingMsg = '加载中...', String errorMsg = '加载失败,点击重试', String finishMsg = '没有更多了'})

Properties

bottomTriggerDistance → double
加载更多底部触发距离
final
child → CustomScrollView
CustomScrollView
final
endLoadMore → bool
到底部才触发加载更多
final
errorMsg → String
Text displayed in case of error
final
finishMsg → String
Text displayed when loading is finished
final
footerHeight → double
底部 loadmore 高度
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingMsg → String
Text displayed during load
final
loadMoreBuilder → LoadMoreBuilder?
自定义加载更多 Widget
final
onLoadMore → LoadMoreCallback
加载更多回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → LoadStatus
加载状态
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited